package be.iminds.ilabt.jfed.experimenter_gui.gts_editor;

import be.iminds.ilabt.jfed.experimenter_gui.gts_editor.events.ShowGTSEditorEvent;
import be.iminds.ilabt.jfed.experimenter_gui.gts_editor.events.ShowGtsTypeEditorEvent;
import be.iminds.ilabt.jfed.experimenter_gui.ui.GtsEditorTabHost;
import com.google.common.eventbus.Subscribe;

import javax.inject.Inject;
import javax.inject.Singleton;
import java.util.Optional;

/**
 * User: twalcari
 * Date: 5/22/2015
 * Time: 14:12
 */
@Singleton
public class GtsEditorEventHandler {

    private final GtsEditorTabFactory gtsEditorTabFactory;
    private final GtsEditorTabHost gtsEditorTabHost;

    @Inject
    public GtsEditorEventHandler(GtsEditorTabFactory gtsEditorTabFactory, GtsEditorTabHost gtsEditorTabHost) {
        this.gtsEditorTabFactory = gtsEditorTabFactory;
        this.gtsEditorTabHost = gtsEditorTabHost;
    }


    @Subscribe
    public void handleShowGTSEditorEvent(ShowGTSEditorEvent event) {
        Optional<GtsTopTypeEditorTab> existingTab = gtsEditorTabHost.getGtsTopTypeEditorTabs().stream()
                .filter(tab -> tab.getGtsTopTypeEditor().getEditableGtsDsl() == event.getEditableGtsDsl())
                .findAny();

        if (existingTab.isPresent()) {
            gtsEditorTabHost.showGtsTopTypeEditorTab(existingTab.get());
            return;
        }

        GtsTopTypeEditorTab newTab =
                gtsEditorTabFactory.createGtsTopTypeEditorTab(event.getEditableGtsDsl());

        gtsEditorTabHost.addGtsTopTypeEditorTab(newTab);
        gtsEditorTabHost.showGtsTopTypeEditorTab(newTab);

    }

    @Subscribe
    public void handleShowGtsTypeEditorEvent(ShowGtsTypeEditorEvent event){
        Optional<GtsChildTypeEditorTab> existingTab = gtsEditorTabHost.getGtsChildTypeEditorTabs().stream()
                .filter(tab -> tab.getGtsChildTypeEditor().getType() == event.getType())
                .findAny();

        if (existingTab.isPresent()) {
            gtsEditorTabHost.showGtsChildTypeEditorTab(existingTab.get());
            return;
        }

        GtsChildTypeEditorTab newTab =
                gtsEditorTabFactory.createGtsChildTypeEditorTab(event.getType(), event.getParentEditor());

        gtsEditorTabHost.addGtsChildTypeEditorTab(newTab);
        gtsEditorTabHost.showGtsChildTypeEditorTab(newTab);

    }
}
